@@ -378,7 +378,7 @@ dbus_svc_remove_path_handler
     Root r;
     const Root *root, *const*rpp;
 
-    if ( ( rootPath == 0L ) || ( *rootPath ='\0') || (*rootPath != '/'))
+    if ( ( rootPath == 0L ) || ( *rootPath =='\0') || (*rootPath != '/'))
     {
 	if( cs->eh != 0L ) (*(cs->eh))("dbus_svc_remove_path: bad root path %s", rootPath);
 	return 0;
@@ -388,7 +388,7 @@ dbus_svc_remove_path_handler
 
     rpp = tfind( &r, &(cs->roots), root_comparator );
     
-    if ( (rpp = 0L) || ( (root=*rpp) == 0L ) )
+    if ( (rpp == 0L) || ( (root=*rpp) == 0L ) )
     {
 	if( cs->eh != 0L ) (*(cs->eh))("dbus_svc_remove_path_handler: cannot remove nonexistent root node %s", rootPath);
 	return 0;
@@ -1394,8 +1394,7 @@ dbus_svc_init
 
     switch
 	(   dbus_bus_request_name 
-	    (   connection, name, DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT , &error
-	    ) 
+	    (   connection, name, 0, &error ) 
 	)
     {   
     case DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER:	
