@@ -1267,7 +1267,7 @@ dhco_value_from_text
 	    }
 	    return octs;
 	}	
-	for(p = (uint8_t*)input; p < (endp-1); p++)
+	for(p = (uint8_t*)input; p < endp; p++)
 	{
 	    if( (*p < 32) || (*p > 127) )
 	    {
@@ -1555,7 +1555,7 @@ dhco_text_from_value
 	if( vlen <= 0 )
 	    return 0;
 	for( p = *value, endp = (*value) + vlen;
-	     p < (endp-1);
+	     p < endp;
 	     p++
 	    )
 	    if( (*p < 32) || (*p > 127) )
