@@ -449,7 +449,7 @@ dhcp_options [DHCP_OPTION_MAX] =
     { "lpr-servers", "IA",				 DHC_O_Universe,	9, 0 },
     { "impress-servers", "IA",			 	 DHC_O_Universe,	10, 0 },
     { "resource-location-servers", "IA",		 DHC_O_Universe,	11, 0 },
-    { "host-name", "X",				 	 DHC_O_Universe,	12, 0 },
+    { "host-name", "t",				 	 DHC_O_Universe,	12, 0 },
     { "boot-size", "S",				 	 DHC_O_Universe,	13, 0 },
     { "merit-dump", "t",				 DHC_O_Universe,	14, 0 },
     { "domain-name", "t",				 DHC_O_Universe,	15, 0 },
@@ -499,7 +499,7 @@ dhcp_options [DHCP_OPTION_MAX] =
     { "dhcp-rebinding-time", "L",			 DHC_O_Universe,	59, 0 },
     { "vendor-class-identifier", "X",		 	 DHC_O_Universe,	60, 0 },
     { "dhcp-client-identifier", "X",		 	 DHC_O_Universe,	61, 0 },
-    { "nwip-domain", "X",				 DHC_O_Universe,	62, 0 },
+    { "nwip-domain", "t",				 DHC_O_Universe,	62, 0 },
     { "nwip-suboptions", "Enwip.",			 DHC_O_Universe,	63, 0 },
     { "nisplus-domain", "t",			 	 DHC_O_Universe,	64, 0 },
     { "nisplus-servers", "IA",			 	 DHC_O_Universe,	65, 0 },
@@ -523,7 +523,7 @@ dhcp_options [DHCP_OPTION_MAX] =
     { 0L,	0L,				 0,	0, 0 },
     { 0L,	0L,				 0,	0, 0 },
     { "nds-servers", "IA",				 DHC_O_Universe,	85, 0 },
-    { "nds-tree-name", "X",				 DHC_O_Universe,	86, 0 },
+    { "nds-tree-name", "t",				 DHC_O_Universe,	86, 0 },
     { "nds-context", "X",				 DHC_O_Universe,	87, 0 },
     { 0L,	0L,				 0,	0, 0 },
     { 0L,	0L,				 0,	0, 0 },
@@ -555,7 +555,7 @@ dhcp_options [DHCP_OPTION_MAX] =
     { 0L,	0L,				 0,	0, 0 },
     { 0L,	0L,				 0,	0, 0 },
     { 0L,	0L,				 0,	0, 0 },
-    { "subnet-selection", "X",			 	 DHC_O_Universe,	118, 0 },
+    { "subnet-selection", "I",			 	 DHC_O_Universe,	118, 0 },
     { 0L,	0L,				 0,	0, 0 },
     { 0L,	0L,				 0,	0, 0 },
     { 0L,	0L,				 0,	0, 0 },
